##  Exporting Initiative Fact Sheets as Jira Work Items
You can create Jira work items directly from individual initiative fact sheets in SAP LeanIX. All relevant fields are prefilled based on your configured field mappings. This capability is available for both parent and child initiatives.
To create a Jira work item from an existing initiative, do the following:
  1. Open an initiative fact sheet and go to the Agile Tracking tab.
  2. To export the fact sheet to Jira, choose Set up Sync and select **Export to Atlassian Jira**.
  3. Choose the connected Jira instance.
  4. Select the target Jira project.
  5. Choose the type of Jira work item to create, such as epic, story, or task.
  6. Choose Create and Sync to complete the export.
The system automatically synchronizes data every 30 minutes.
